// This file is part of QuickPlot

function PLT_Macro_createVar(dataIndex_ZeroBase, varName, expression)
    
    /****************************************************************
     * Create a new variable
     *
     * Input Arguments:
     *     dataIndex_ZeroBase -- data index (zero-base)
     *     varName -- variable name for the new variable
     *     expression -- expression for the new variable 
     ****************************************************************/
    global PLT
    
    DataList = PLT_Class_DataList();

    dataIndex_OneBase = dataIndex_ZeroBase + 1;

    try
        data = PLT.dataList.data(dataIndex_OneBase);
    
        numeric_column = evstr(expression);
        [nr, nc] = size(numeric_column);
        if nr ~= data.nRow | nc ~= 1 then
            msg = msprintf('Expression must produce a column vector of length %d.', data.nRow);
            error(msg);
        end
        
        data.nCol = data.nCol + 1;
        data.varNames = [data.varNames; varName];
        data.numeric = [data.numeric, numeric_column];
    
        PLT.dataList =  DataList.replaceData(PLT.dataList, dataIndex_OneBase, data);
    catch
        msg = lasterror();
        TCL_EvalStr([
            'if {[winfo exists .w_CreateVariable] == 0} {dbox_CreateVar false}';
            'tk_messageBox -parent .w_CreateVariable -type ok -icon error -title ""Error!"" -message {' + strcat(msg, ' ') + '}'; 
        ]);
        error(msg);
    end
    
    TCL_EvalStr([
        'lset VarNamesList ' + string(dataIndex_ZeroBase) + ' [list ' + PLT_Util_strvec2list(data.varNames) + ']';
        'cb_filter_xvar';
        'cb_filter_yvar';
        'cb_ckb_Browse';
    ]);
   
endfunction
