// This file is part of QuickPlot

function flg_rep = PLT_Macro_dboxExportCurveToWS()
    
    /****************************************************************
     * Open a dialog box to export curve data to workspace
     *
     * Output Arguments:
     *     flg_rep ... the caller may call this function repeatedly if flg_rep == 1.
     ****************************************************************/

    if isempty(winsid()) then // if there is no figure
        flg_rep = 0;
        return;
    end
    
    h = gca();
    if isempty(h.children) then // if there is no element in the axes
        flg_rep = 0;
        return;
    end

    polylineHandles = [];
    for i = 1:length(h.children)
        if h.children(i).type == "Legend" then
            legendHandle = h.children(i);
            legendText = legendHandle.text;
        elseif h.children(i).type == "Polyline" then
            polylineHandles = [h.children(i), polylineHandles];
        else
            // do nothing
        end
    end

    while 1
        num = x_choose(legendText,'Select a curve to export','Cancel');

        if num > 0
            [ok, varname] = getvalue('Enter a variable to which the data is substituted',['Variable Name'],list('str',1),['curve_data']);
            if ok
                curve_data = polylineHandles(num).data;
                str = varname + '= resume(curve_data);'; // resume terminates the function
                flg_rep = 1;
                execstr(str); // return
            else
                continue;
            end
        else
            flg_rep = 0;
            return;
        end
    end

endfunction
