// This file is part of QuickPlot

function PLT_Macro_importData(dataName, filepath, skiprows, sep, varNameRow)
    
    /****************************************************************
     * Import data from file
     *
     * Input Arguments:
     *     dataName -- Data name
     *     filepath -- Path of the file
     *     skiprows -- Number of rows to be skipped
     *     sep -- Separator character
     *     varNameRow -- Row number where variable names reside, set this to -1 if not importing variable names
     ****************************************************************/
    
    global PLT
    
    Data = PLT_Class_Data();
    DataList = PLT_Class_DataList();
    
    try
        data = Data.new();
        data.name = dataName;
        data = Data.importNumeric(data, filepath, skiprows, sep);
        
        if varNameRow > 0 then
            data = Data.importVarNames(data, filepath, varNameRow, sep);
        else
            nc = data.nCol;
            for i = 1:nc
                varNames(i) = 'column_' + string(i);
            end
            data.varNames = varNames;
        end
    catch
        msg = lasterror();
        TCL_EvalStr([
            'tk_messageBox -parent .w -type ok -icon error -title ""Error!"" -message {' + strcat(msg, ' ') + '}'; 
        ]);
        error(msg);
    end
    
    PLT.dataList =  DataList.addData(PLT.dataList, data);
    
    TCL_EvalStr([
        'lappend DataNames {' + data.name + '}';
        'lappend VarNamesList [list ' + PLT_Util_strvec2list(data.varNames) + ']';
        'cb_filter_data';
    ]);
    
endfunction
