// This file is part of QuickPlot

function PLT_Macro_importVarNames(dataIndex_ZeroBase, filepath)
    
    /****************************************************************
     * Import variable names from file (each row is a label)
     *
     * Input Arguments:
     *     dataIndex_ZeroBase -- data index (zero-base)
     *     filepath -- Path of the file
     ****************************************************************/
    
    global PLT
    
    DataList = PLT_Class_DataList();
    
    dataIndex_OneBase = dataIndex_ZeroBase + 1;
    
    data = PLT.dataList.data(dataIndex_OneBase);
    
    try
        fid = mopen(filepath, 'r');
        lines = stripblanks(mgetl(fid), %t);
        mclose(fid);
        
        varNames = [];
        for i = 1:data.nCol
            varName = lines(i);
            if length(varName) == 0
                msg = msprintf('Variable name cannot be an empty string at row %d.', i);
                error(msg);
            end
            if ~isempty(find(varNames == varName))
                msg = msprintf('There is a duplicated variable name ""%s"" at row %d. Please choose a unique name for each variable.', varName, i);
                error(msg);
            end
            varNames(i,1) = varName;
        end
        if ~isempty(find(length(lines(data.nCol+1:$)) > 0))
            msg = msprintf('The number of variable names must match the number of columns of data (%d).', data.nCol);
            error(msg);
        end
    
        data.varNames = varNames;
        PLT.dataList =  DataList.replaceData(PLT.dataList, dataIndex_OneBase, data);
    catch
        msg = lasterror();
        TCL_EvalStr([
            'tk_messageBox -parent .w -type ok -icon error -title ""Error!"" -message {' + strcat(msg, ' ') + '}'; 
        ]);
        error(msg);
    end
    
    TCL_EvalStr([
        'lset VarNamesList ' + string(dataIndex_ZeroBase) + ' [list ' + PLT_Util_strvec2list(varNames) + ']';
        'cb_filter_xvar';
        'cb_filter_yvar';
        'cb_ckb_Browse';
    ]);
    
endfunction
