// This file is part of QuickPlot

function PLT_Macro_setProperties(prop)
    
    if ~isempty(winsid()) then
        
        h = gca();
        
        drawlater();
        
        // Title & Labels
        title(prop.title, 'fontsize', prop.fontSize);
        xlabel(prop.xLabel, 'fontsize', prop.fontSize);
        ylabel(prop.yLabel, 'fontsize', prop.fontSize);
        h.font_size = prop.fontSize;
        
        // Grid
        if prop.gridYesNo ~= 0
            h.grid = [1 1].*prop.gridColor; // grid on
        else
            h.grid = [-1, -1]; // grid off
        end
        
        // X Limit
        if prop.xLimYesNo ~= 0 then
            h.data_bounds(:,1) = [prop.xMin; prop.xMax];
        else
            default_data_bounds = h.user_data;
            h.data_bounds(:,1) = default_data_bounds(:,1);
        end
        
        // Y Limit
        if prop.yLimYesNo ~= 0 then
            h.data_bounds(:,2) = [prop.yMin; prop.yMax];
        else
            default_data_bounds = h.user_data;
            h.data_bounds(:,2) = default_data_bounds(:,2);
        end
        
        if ~isempty(h.children) then
            for i = 1:length(h.children)
                
                e = h.children(i);
                
                select e.type
                case 'Polyline' then
                    
                    // Line
                    if prop.lineYesNo ~= 0
                        e.line_mode = 'on';
                    else
                        e.line_mode = 'off';
                    end
                    e.thickness = prop.lineThickness;

                    // Mark
                    if prop.markYesNo ~= 0
                        e.mark_mode = 'on';
                    else
                        e.mark_mode = 'off';
                    end
                    e.mark_size_unit = 'point';
                    e.mark_size = prop.markSize;

                case 'Legend' then

                    // Legend
                    if prop.legendYesNo ~= 0
                        e.visible = 'on';
                    else
                        e.visible = 'off';
                    end
                    e.font_size = prop.legendFontSize;
                    e.legend_location = prop.legendLocation;
                    
                else
                    // do nothing
                end
            end
        end
        
        drawnow();
    end;
    
endfunction
