# This file is part of QuickPlot

#***********************************************************************
# Delete Data Dialog Box Module
#
#     Construct a dialog box for deleting data
#
# Public Procedures:
#     dbox_DeleteData -- create a dialog box for deleting data
#
# Namespace:
#     ns_DeleteData
#
# Private Procedures:
#     cb_btn_Delete -- callback to the "Delete" button
#     cb_btn_Close -- callback to the "Close" button
#***********************************************************************

#***********************************************************************
#  dbox_DeleteData -- create a dialog box for deleting data
#***********************************************************************
proc dbox_DeleteData {} {

	global DataNames; # list of all data names
	
	# Check if data exist
	if {[llength $DataNames] < 1} {
		tk_messageBox -parent .w_PLT -type ok -icon error -title "Error!"\
			-message "There is no data."
		return
	}

	#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
	# Delete Data Dialog Box
	#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/

	# Create a new top-level window for the dialog box
	toplevel .w_PLT_DeleteData
	wm title .w_PLT_DeleteData "Delete Data"
	wm iconbitmap .w_PLT_DeleteData $::ICON_FILE

	# In the dialog box, create "Setting" and "Buttons" frames
	set ::ns_DeleteData::frameSetting [set frameSetting [frame .w_PLT_DeleteData.f_Setting]]
	set ::ns_DeleteData::frameButtons [set frameButtons [frame .w_PLT_DeleteData.f_Buttons]]
	grid $frameSetting -padx 10 -pady 10 -sticky news
	grid $frameButtons -padx 10 -pady 10 -sticky news
	grid columnconfigure .w_PLT_DeleteData 0 -weight 1
	grid rowconfigure .w_PLT_DeleteData 0 -weight 1

	# In Setting frame:
	label $frameSetting.lab_Instruction -text "Select data to delete" -anchor w
	listbox $frameSetting.lsb_Data -height 7\
		-xscrollcommand {$frameSetting.scrl_Data_h set}\
		-yscrollcommand {$frameSetting.scrl_Data_v set}\
		-selectmode extended -listvariable DataNames -activestyle none
	scrollbar $frameSetting.scrl_Data_h -orient horizontal\
		-command "$frameSetting.lsb_Data xview"
	scrollbar $frameSetting.scrl_Data_v -orient vertical\
		-command "$frameSetting.lsb_Data yview"
	grid $frameSetting.lab_Instruction -sticky w
	grid $frameSetting.lsb_Data $frameSetting.scrl_Data_v -sticky news
	grid $frameSetting.scrl_Data_h -sticky news
	grid columnconfigure $frameSetting 0 -weight 1
	grid rowconfigure $frameSetting 1 -weight 1
	$frameSetting.lsb_Data configure\
		-xscrollcommand [list sbset $frameSetting.scrl_Data_h]\
		-yscrollcommand [list sbset $frameSetting.scrl_Data_v]
	
	# In Buttons frame:
	button $frameButtons.btn_Delete -text Delete -width 15 -command ::ns_DeleteData::cb_btn_Delete
	button $frameButtons.btn_Close -text Close -width 15 -command ::ns_DeleteData::cb_btn_Close
	pack $frameButtons.btn_Close $frameButtons.btn_Delete  -padx 10 -side right
	
	# Set grab to this window
	grab set .w_PLT_DeleteData
}

#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
# Delete Data Namespace
#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
namespace eval ns_DeleteData {
	
	# Namespace variables
	variable frameSetting
	variable frameButtons
	
	#***********************************************************************
	#  cb_btn_Delete -- callback to the "Delete" button
	#***********************************************************************
	proc cb_btn_Delete {} {
		global DataNames; # list of all data names
		global VarNamesList; # list of lists of variable names
		global FilteredXVars; # filtered list of x variables
		global FilteredYVars; # filtered list of y variables
		global SelectedDataIndices; # list of indices of currently selected data
		global SelectedXVars; # list of currently selected x variables
		global SelectedYVars; # list of currently selected y variables
		
		variable frameSetting
		
		set dataIndices [$frameSetting.lsb_Data curselection]
		
		if {$dataIndices eq ""} {
			tk_messageBox -parent .w_PLT_DeleteData -type ok -icon error -title "Error!"\
				-message "No data is selected."
			return
		}
		
		for {set i 0} {$i < [llength $dataIndices]} {incr i} {
			set index [lindex $dataIndices end-$i]
			ScilabEval "PLT_Macro_deleteData($index);" "seq"
			set DataNames [lreplace $DataNames $index $index]
			set VarNamesList [lreplace $VarNamesList $index $index]
		}
		
		cb_filter_data
		cb_ckb_Browse
		
		set FilteredXVars {}
		set FilteredYVars {}
		
		set SelectedDataIndices {}
		set SelectedXVars {}
		set SelectedYVars {}
	}
	
	#***********************************************************************
	#  cb_btn_Close -- callback to the "Close" button
	#***********************************************************************
	proc cb_btn_Close {} {
		destroy .w_PLT_DeleteData
	}
}