# This file is part of QuickPlot

#***********************************************************************
# Insert Varval Dialog Box Module
#
#     Construct a dialog box for inserting varval function in an expression editor
#
# Public Procedures:
#     dbox_InsertVarval -- create a dialog box for inserting varval function in an expression editor
#
# Namespace:
#     ns_InsertVarval
#
# Private Procedures:
#     update_varnames -- refresh variable names according to the selected data
#     cb_btn_Insert -- callback to the "Insert" button
#     cb_btn_Cancel -- callback to the "Cancel" button
#***********************************************************************

#***********************************************************************
# dbox_InsertVarval -- create a dialog box for inserting varval function in an expression editor
#***********************************************************************
proc dbox_InsertVarval {pathName dataName} {

	global DataNames; # list of all data names
	global VarNamesList; # list of lists of variable names
	
	# Check if data exist
	if {[llength $DataNames] < 1} {
		tk_messageBox -parent .w_PLT -type ok -icon error -title "Error!"\
			-message "There is no data."
		return
	}
	
	# Set some of the namespace variables
	set ::ns_InsertVarval::dataName $dataName;
	set ::ns_InsertVarval::varNames [lindex $VarNamesList [lsearch -exact $DataNames $dataName]]
	set ::ns_InsertVarval::varName [lindex $::ns_InsertVarval::varNames 0]

	#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
	# Insert Varval Dialog Box
	#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
	
	# Create a new top-level window for the dialog box
	toplevel .w_PLT_InsertVarval
	wm title .w_PLT_InsertVarval "Insert Varval"
	wm iconbitmap .w_PLT_InsertVarval $::ICON_FILE
	
	# In the dialog box, create "Setting" and "Buttons" frames
	set ::ns_InsertVarval::frameSetting [set frameSetting [frame .w_PLT_InsertVarval.f_Setting]]
	set ::ns_InsertVarval::frameButtons [set frameButtons [frame .w_PLT_InsertVarval.f_Buttons]]
	grid $frameSetting -padx 10 -pady 10 -sticky ew
	grid $frameButtons -padx 10 -pady 10 -sticky ew
	grid columnconfigure .w_PLT_InsertVarval 0 -weight 1

	# In Setting frame:
	label $frameSetting.lab_DataName -text "Data name" -anchor w
	ttk::combobox $frameSetting.cmb_DataName -textvariable ::ns_InsertVarval::dataName -values $DataNames -state readonly
	bind $frameSetting.cmb_DataName <<ComboboxSelected>> ::ns_InsertVarval::update_varnames
	label $frameSetting.lab_VarName -text "Variable name" -anchor w
	ttk::combobox $frameSetting.cmb_VarName -textvariable ::ns_InsertVarval::varName -values $::ns_InsertVarval::varNames -state readonly
	grid $frameSetting.lab_DataName $frameSetting.cmb_DataName -padx 4 -pady 2 -sticky ew
	grid $frameSetting.lab_VarName $frameSetting.cmb_VarName -padx 4 -pady 2 -sticky ew
	grid columnconfigure $frameSetting 1 -weight 1

	# In Buttons frame:
	button $frameButtons.btn_Insert -text Insert -width 15 -command "::ns_InsertVarval::cb_btn_Insert $pathName"
	button $frameButtons.btn_Cancel -text Cancel -width 15 -command ::ns_InsertVarval::cb_btn_Cancel
	pack $frameButtons.btn_Cancel $frameButtons.btn_Insert -padx 10 -side right
	
	# Set grab to this window
	grab set .w_PLT_InsertVarval
}

#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
# Insert Varval Namespace
#_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/_/
namespace eval ns_InsertVarval {

	# Namespace variables
	variable frameSetting
	variable frameButtons
	variable dataName
	variable varNames
	variable varName
	
	#***********************************************************************
	# update_varnames -- refresh variable names according to the selected data
	#***********************************************************************
	proc update_varnames {} {
		global VarNamesList; # list of lists of variable names
		
		variable frameSetting
		variable varNames
		variable varName
		
		set dataIndex [$frameSetting.cmb_DataName current]
		set varNames [lindex $VarNamesList $dataIndex]
		$frameSetting.cmb_VarName configure -values $varNames
		set varName [lindex $varNames 0]
	}
	
	#***********************************************************************
	# cb_btn_Insert -- callback to the "Insert" button
	#***********************************************************************
	proc cb_btn_Insert {pathName} {
		global DataNames; # list of all data names

		variable dataName
		variable varName
		
		$pathName insert insert "PLT_varval(\"$dataName\",\"$varName\")"
		
		destroy .w_PLT_InsertVarval
	}
	
	#***********************************************************************
	# cb_btn_Cancel -- callback to the "Cancel" button
	#***********************************************************************
	proc cb_btn_Cancel {} {
		destroy .w_PLT_InsertVarval
	}
}