# This file is part of QuickPlot

#***********************************************************************
# Data Pop-up Menu Module
#
#     Procedures for the pop-up menu of data
#
# Public Procedures:
#     pop_DeleteData -- delete data from the pop-up menu
#     pop_ShowData -- show data info from the pop-up menu
#***********************************************************************

#***********************************************************************
#  pop_DeleteData -- delete data from the pop-up menu
#***********************************************************************
proc pop_DeleteData {} {

	global DataNames; # list of all data names
	global VarNamesList; # list of lists of variable names
	global FilteredXVars; # filtered list of x variables
	global FilteredYVars; # filtered list of y variables
	global SelectedDataIndices; # list of indices of currently selected data
	global SelectedXVars; # list of currently selected x variables
	global SelectedYVars; # list of currently selected y variables
	
	if {[llength $SelectedDataIndices] == 1} {
		set message "Is it OK to delete '[lindex $DataNames $SelectedDataIndices]'?"
	} else {
		set message "Is it OK to delete these [llength $SelectedDataIndices] data items?"
	}
		
	set popupStatus [tk_messageBox -parent .w_PLT -type yesno -icon question -title "Confirmation" -message $message]
	
	if {$popupStatus eq "yes"} {
		for {set i 0} {$i < [llength $SelectedDataIndices]} {incr i} {
			set index [lindex $SelectedDataIndices end-$i]
			ScilabEval "PLT_Macro_deleteData($index);" "seq"
			set DataNames [lreplace $DataNames $index $index]
			set VarNamesList [lreplace $VarNamesList $index $index]
		}
		cb_filter_data
		cb_ckb_Browse
		
		set FilteredXVars {}
		set FilteredYVars {}
		
		set SelectedDataIndices {}
		set SelectedXVars {}
		set SelectedYVars {}
	}
}

#***********************************************************************
#  pop_ShowData -- show data info from the pop-up menu
#***********************************************************************
proc pop_ShowData {} {
	global SelectedDataIndices; # list of indices of currently selected data
	
	foreach index $SelectedDataIndices {
		ScilabEval "PLT_Macro_showData($index);" "seq"
	}
}