# This file is part of QuickPlot

#***********************************************************************
# Variable Pop-up Menu Module
#
#     Procedures for the pop-up menu of variables
#
# Public Procedures:
#     pop_DeleteVariable -- delete variables from the pop-up menu
#***********************************************************************

#***********************************************************************
#  pop_DeleteVariable -- delete variables from the pop-up menu
#***********************************************************************
proc pop_DeleteVariable {xory} {
	global VarNamesList; # list of lists of variable names
	global SelectedDataIndices; # list of indices of currently selected data
	global SelectedXVars; # list of currently selected x variables
	global SelectedYVars; # list of currently selected y variables
	
	switch -- $xory {
		"x" {set selectedVars $SelectedXVars}
		"y" {set selectedVars $SelectedYVars}
		default {error "Error! Unknown argument value. Must be 'x' or 'y'."}
	}
	
	if {[llength $selectedVars] == 1} {
		set message "Is it OK to delete '$selectedVars'?"
	} else {
		set message "Is it OK to delete these [llength $selectedVars] variables?"
	}
		
	set popupStatus [tk_messageBox -parent .w_PLT -type yesno -icon question -title "Confirmation" -message $message]
	
	if {$popupStatus eq "yes"} {
		foreach dataIndex $SelectedDataIndices {
			set varNames [lindex $VarNamesList $dataIndex]
			for {set i 0} {$i < [llength $selectedVars]} {incr i} {
				set varName [lindex $selectedVars end-$i]
				set varIndex [lindex [lsearch -exact -all $varNames $varName] end]
				ScilabEval "PLT_Macro_deleteVar($dataIndex, $varIndex);" "seq"
				set varNames [lreplace $varNames $varIndex $varIndex]
			}
			lset VarNamesList $dataIndex $varNames
			cb_filter_xvar
			cb_filter_yvar
			cb_ckb_Browse
		}
	}
}