# This file is part of QuickPlot

#***********************************************************************
# Callbacks Module
#
#     Common callback procedures for QuickPlot
#
# Public Procedures:
#     cb_select_data_press -- callback when the data list-box is mouse-pressed
#     cb_select_data_release -- callback when the data list-box is mouse-released
#     cb_select_xvar_press -- callback when the x variable list box is mouse-pressed
#     cb_select_xvar_release -- callback when the x variable list box is mouse-released
#     cb_select_yvar_press -- callback when the y variable list box is mouse-pressed
#     cb_select_yvar_release -- callback when the y variable list box is mouse-released
#     cb_ckb_XVar -- callback when the "X Variable" check-box is clicked
#     cb_filter_data -- callback for filtering data
#     cb_filter_xvar -- callback for filtering x variables
#     cb_filter_yvar -- callback for filtering y variables
#     cb_ckb_DataFilter -- callback when the "Data Filter" check-box is clicked
#     cb_ckb_XVarFilter -- callback when the "X Variable Filter" check-box is clicked
#     cb_ckb_YVarFilter -- callback when the "Y Variable Filter" check-box is clicked
#     cb_cmb_CurrentFigID -- callback when the "Current Figure" combo-box is selected
#     cb_ckb_Browse -- callback when the "Browse" check-box is clicked
#     cb_ckb_ApplyPropAlways -- callback when the "Apply always" check-box is clicked
#     cb_ckb_Legend -- callback when the "Legend" check-box is clicked
#     cb_ckb_Grid -- callback when the "Grid" check-box is clicked
#     cb_ckb_Line -- callback when the "Line" check-box is clicked
#     cb_ckb_Mark -- callback when the "Mark" check-box is clicked
#     cb_ckb_XLim -- callback when the "X Limits" check-box is clicked
#     cb_ckb_YLim -- callback when the "Y Limits" check-box is clicked
#     cb_btn_ShowHideProperty -- callback when the "Show/Hide Property Setting" button is pushed
#***********************************************************************

#***********************************************************************
# cb_select_data_press -- callback when the data list box is mouse-pressed
#***********************************************************************
proc cb_select_data_press {} {
	mac_decolor_data_listbox
}

#***********************************************************************
# cb_select_data_release -- callback when the data list box is mouse-released
#***********************************************************************
proc cb_select_data_release {} {
	global XVarYesNo; # flag: whether to use x variable or not
	
	mac_get_SelectedDataIndices
	mac_paint_data_listbox
	
	mac_update_XVar
	mac_filter_SelectedXVars
	if {$XVarYesNo == 1} {
		mac_paint_xvar_listbox
	}
	
	mac_update_YVar
	mac_filter_SelectedYVars
	mac_paint_yvar_listbox
	
	# If in browse mode, clear figure and plot data in the current figure
	cb_ckb_Browse
}

#***********************************************************************
# cb_select_xvar_press -- callback when the xvar list box is mouse-pressed
#***********************************************************************
proc cb_select_xvar_press {} {
	mac_decolor_xvar_listbox
}

#***********************************************************************
# cb_select_xvar_release -- callback when the xvar list box is mouse-released
#***********************************************************************
proc cb_select_xvar_release {} {
	global XVarYesNo; # flag: whether to use x variable or not
	
	mac_get_SelectedXVars
	if {$XVarYesNo == 1} {
		mac_paint_xvar_listbox
	}
	
	# If in browse mode, clear figure and plot data in the current figure
	cb_ckb_Browse
}

#***********************************************************************
# cb_select_yvar_press -- callback when the yvar list box is mouse-pressed
#***********************************************************************
proc cb_select_yvar_press {} {
	mac_decolor_yvar_listbox
}

#***********************************************************************
# cb_select_yvar_release -- callback when the yvar list box is mouse-pressed
#***********************************************************************
proc cb_select_yvar_release {} {
	
	mac_get_SelectedYVars
	mac_paint_yvar_listbox
	
	# If in browse mode, clear figure and plot data in the current figure
	cb_ckb_Browse
}

#***********************************************************************
# cb_ckb_XVar -- callback when the "X Variable" check-box is clicked
#***********************************************************************
proc cb_ckb_XVar {} {
	global XVarYesNo; # flag: whether to use x variable or not
	global XVarFilterYesNo; # flag: whether to filter x variables or not
	
	if {$XVarYesNo == 1} {
		$::frameXVar.lsb_XVar configure -state normal
		$::frameXVar.ckb_XVarFilter configure -state normal
		if {$XVarFilterYesNo == 1} {
			$::frameXVar.cmb_XVarFilter configure -state normal
		}
	} else {
		$::frameXVar.lsb_XVar configure -state disabled
		$::frameXVar.ckb_XVarFilter configure -state disabled
		$::frameXVar.cmb_XVarFilter configure -state disabled
	}
	# If in browse mode, clear figure and plot data in the current figure
	cb_ckb_Browse
}

#***********************************************************************
# cb_filter_data -- callback for filtering data
#***********************************************************************
proc cb_filter_data {} {
	global XVarYesNo; # flag: whether to use x variable or not
	global SelectedDataIndices; # list of indices of currently selected data

	mac_filter_data
	mac_filter_SelectedDataIndices
	mac_paint_data_listbox
	
	if {$SelectedDataIndices == ""} {
		cb_filter_xvar
		cb_filter_yvar
	}
}

#***********************************************************************
# cb_filter_xvar -- callback for filtering x variables
#***********************************************************************
proc cb_filter_xvar {} {
	global XVarYesNo; # flag: whether to use x variable or not

	mac_update_XVar
	mac_filter_SelectedXVars
	if {$XVarYesNo == 1} {
		$::frameXVar.lsb_XVar selection clear 0 end
		mac_paint_xvar_listbox
	}
}

#***********************************************************************
# cb_filter_yvar -- callback for filtering y variables
#***********************************************************************
proc cb_filter_yvar {} {

	mac_update_YVar
	mac_filter_SelectedYVars
	$::frameYVar.lsb_YVar selection clear 0 end
	mac_paint_yvar_listbox
}

#***********************************************************************
# cb_ckb_DataFilter -- callback when the "Data Filter" check-box is clicked
#***********************************************************************
proc cb_ckb_DataFilter {} {
	global DataFilterYesNo; # flag: whether to filter data or not
	
	if {$DataFilterYesNo == 1} {
		$::frameData.cmb_DataFilter configure -state normal
	} else {
		$::frameData.cmb_DataFilter configure -state disabled
	}
	cb_filter_data
	cb_ckb_Browse
}

#***********************************************************************
# cb_ckb_XVarFilter -- callback when the "X Variable Filter" check-box is clicked
#***********************************************************************
proc cb_ckb_XVarFilter {} {
	global XVarFilterYesNo; # flag: whether to filter x variables or not
	
	if {$XVarFilterYesNo == 1} {
		$::frameXVar.cmb_XVarFilter configure -state normal
	} else {
		$::frameXVar.cmb_XVarFilter configure -state disabled
	}
	cb_filter_xvar
	cb_ckb_Browse
}

#***********************************************************************
# cb_ckb_YVarFilter -- callback when the "Y Variable Filter" check-box is clicked
#***********************************************************************
proc cb_ckb_YVarFilter {} {
	global YVarFilterYesNo; # flag: whether to filter y variables or not
	
	if {$YVarFilterYesNo == 1} {
		$::frameYVar.cmb_YVarFilter configure -state normal
	} else {
		$::frameYVar.cmb_YVarFilter configure -state disabled
	}
	cb_filter_yvar
	cb_ckb_Browse
}

#***********************************************************************
# cb_cmb_CurrentFigID -- callback when the "Current Figure" combo-box is selected
#***********************************************************************
proc cb_cmb_CurrentFigID {} {
	global CurrentFigID
	
	mac_set_current_fig $CurrentFigID
}

#***********************************************************************
# cb_ckb_Browse -- callback when the Browse check-box is clicked
#***********************************************************************
proc cb_ckb_Browse {} {
	global SelectedDataIndices; # list of indices of currently selected data
	global SelectedXVars; # list of currently selected x variables
	global SelectedYVars; # list of currently selected y variables
	global XVarYesNo; # flag: whether to use x variable or not
	global BrowseYesNo; # flag: whether if browse mode is on or not
	
	# If in browse mode, clear figure and plot data in the current figure
	if {$BrowseYesNo == 1} {
		mac_clear_figure
		if {$SelectedDataIndices ne "" && $SelectedYVars ne ""} {
			if {$SelectedXVars ne "" || $XVarYesNo == 0} {
				mac_plot_data 0
			}
		}
	}
}

#***********************************************************************
# cb_ckb_ApplyPropAlways -- callback when the "Apply always" check-box is clicked
#***********************************************************************
proc cb_ckb_ApplyPropAlways {} {
	global ApplyPropAlwaysYesNo; # flag: whether if the graph property is applied always or not
	
	if {$ApplyPropAlwaysYesNo == 1} {
		mac_set_properties
	}
}

#***********************************************************************
# cb_ckb_Legend -- callback when the "Legend" check-box is clicked
#***********************************************************************
proc cb_ckb_Legend {} {
	global PlotLegendYesNo; # flag: whether to show legend or not
	
	if {$PlotLegendYesNo == 1} {
		$::frameLegend.lab_LegendFontSize configure -state normal
		$::frameLegend.cmb_LegendFontSize configure -state readonly
		$::frameLegend.lab_LegendLocation configure -state normal
		$::frameLegend.cmb_LegendLocation configure -state readonly
	} else {
		$::frameLegend.lab_LegendFontSize configure -state disabled
		$::frameLegend.cmb_LegendFontSize configure -state disabled
		$::frameLegend.lab_LegendLocation configure -state disabled
		$::frameLegend.cmb_LegendLocation configure -state disabled
	}
}

#***********************************************************************
# cb_ckb_Grid -- callback when the "Grid" check-box is clicked
#***********************************************************************
proc cb_ckb_Grid {} {
	global PlotGridYesNo; # flag: whether to show grids or not
	
	if {$PlotGridYesNo == 1} {
		$::frameGrid.lab_GridColor configure -state normal
		$::frameGrid.cmb_GridColor configure -state readonly
	} else {
		$::frameGrid.lab_GridColor configure -state disabled
		$::frameGrid.cmb_GridColor configure -state disabled
	}
}

#***********************************************************************
# cb_ckb_Line -- callback when the "Line" check-box is clicked
#***********************************************************************
proc cb_ckb_Line {} {
	global PlotLineYesNo; # flag: whether to show lines or not
	
	if {$PlotLineYesNo == 1} {
		$::framePolyline.cmb_LineThickness configure -state readonly
	} else {
		$::framePolyline.cmb_LineThickness configure -state disabled
	}
}

#***********************************************************************
# cb_ckb_Mark -- callback when the "Mark" check-box is clicked
#***********************************************************************
proc cb_ckb_Mark {} {
	global PlotMarkYesNo; # flag: whether to show marks or not
	
	if {$PlotMarkYesNo == 1} {
		$::framePolyline.cmb_MarkSize configure -state readonly
	} else {
		$::framePolyline.cmb_MarkSize configure -state disabled
	}
}

#***********************************************************************
# cb_ckb_XLim -- callback when the "X Limits" check-box is clicked
#***********************************************************************
proc cb_ckb_XLim {} {
	global PlotXLimYesNo; # flag: whether to use x limits or not
	
	if {$PlotXLimYesNo == 1} {
		$::frameXLim.lab_XMin configure -state normal
		$::frameXLim.ent_XMin configure -state normal
		$::frameXLim.lab_XMax configure -state normal
		$::frameXLim.ent_XMax configure -state normal
	} else {
		$::frameXLim.lab_XMin configure -state disabled
		$::frameXLim.ent_XMin configure -state disabled
		$::frameXLim.lab_XMax configure -state disabled
		$::frameXLim.ent_XMax configure -state disabled
	}
}

#***********************************************************************
# cb_ckb_YLim -- callback when the "Y Limits" check-box is clicked
#***********************************************************************
proc cb_ckb_YLim {} {
	global PlotYLimYesNo; # flag: whether to use x limits or not
	
	if {$PlotYLimYesNo == 1} {
		$::frameYLim.lab_YMin configure -state normal
		$::frameYLim.ent_YMin configure -state normal
		$::frameYLim.lab_YMax configure -state normal
		$::frameYLim.ent_YMax configure -state normal
	} else {
		$::frameYLim.lab_YMin configure -state disabled
		$::frameYLim.ent_YMin configure -state disabled
		$::frameYLim.lab_YMax configure -state disabled
		$::frameYLim.ent_YMax configure -state disabled
	}
}

#***********************************************************************
# cb_btn_ShowHideProperty -- callback when the "Show/Hide Property Setting" button is pushed
#***********************************************************************
proc cb_btn_ShowHideProperty {} {
	global PropertyIsShown; # flag: whether if Graph Property GUI is shown or not
	
	if {$PropertyIsShown == 1} { # currently shown
		# Hide
		set w_width [lindex [grid bbox .w_PLT] 2]
		set w_height [lindex [grid bbox .w_PLT] 3]
		set f_height [lindex [grid bbox $::frameLower] 3]
		grid remove $::frameLower
		wm geometry .w_PLT "${w_width}x[expr {$w_height - $f_height}]"
		
		$::buttonShowHideProperty configure -text {Show Property Setting >>}
		set PropertyIsShown 0
	} else {                     # currently hidden
		# Show
		set w_width [lindex [grid bbox .w_PLT] 2]
		set w_height [lindex [grid bbox .w_PLT] 3]
		grid $::frameLower
		set f_height [lindex [grid bbox $::frameLower] 3]
		wm geometry .w_PLT "${w_width}x[expr {$w_height + $f_height}]"

		$::buttonShowHideProperty configure -text {Hide Property Setting <<}
		set PropertyIsShown 1
	}
}
